@@ -13,10 +13,10 @@
 # under the License.
 
 import unittest
+from unittest import mock
 
 import cliff.app
 import cliff.commandmanager
-import mock
 
 from kayobe import ansible
 from kayobe.cli import commands
@@ -317,17 +317,17 @@ class TestCase(unittest.TestCase):
                     utils.get_data_files_path("ansible", "ssh-known-host.yml"),
                     utils.get_data_files_path(
                         "ansible", "kayobe-ansible-user.yml"),
-                    utils.get_data_files_path("ansible", "yum.yml"),
-                    utils.get_data_files_path("ansible", "dnf.yml"),
                     utils.get_data_files_path("ansible", "pip.yml"),
                     utils.get_data_files_path(
                         "ansible", "kayobe-target-venv.yml"),
                     utils.get_data_files_path("ansible", "users.yml"),
+                    utils.get_data_files_path("ansible", "dnf.yml"),
                     utils.get_data_files_path("ansible", "dev-tools.yml"),
                     utils.get_data_files_path("ansible", "network.yml"),
                     utils.get_data_files_path("ansible", "sysctl.yml"),
-                    utils.get_data_files_path("ansible", "ntp.yml"),
+                    utils.get_data_files_path("ansible", "timezone.yml"),
                     utils.get_data_files_path("ansible", "mdadm.yml"),
+                    utils.get_data_files_path("ansible", "luks.yml"),
                     utils.get_data_files_path("ansible", "lvm.yml"),
                     utils.get_data_files_path(
                         "ansible", "seed-hypervisor-libvirt-host.yml"),
@@ -461,28 +461,18 @@ class TestCase(unittest.TestCase):
         ]
         self.assertEqual(expected_calls, mock_run.call_args_list)
 
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_config_dump")
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
     @mock.patch.object(commands.KollaAnsibleMixin,
                        "run_kolla_ansible_seed")
-    def test_seed_host_configure(self, mock_kolla_run, mock_run, mock_dump):
+    def test_seed_host_configure(self, mock_kolla_run, mock_run):
         command = commands.SeedHostConfigure(TestApp(), [])
         parser = command.get_parser("test")
         parsed_args = parser.parse_args([])
-        mock_dump.return_value = {
-            "seed": {"kayobe_ansible_user": "stack"}
-        }
 
         result = command.run(parsed_args)
         self.assertEqual(0, result)
 
-        expected_calls = [
-            mock.call(mock.ANY, hosts="seed", tags="dump-config")
-        ]
-        self.assertEqual(expected_calls, mock_dump.call_args_list)
-
         expected_calls = [
             mock.call(
                 mock.ANY,
@@ -495,12 +485,11 @@ class TestCase(unittest.TestCase):
                     utils.get_data_files_path("ansible", "ssh-known-host.yml"),
                     utils.get_data_files_path(
                         "ansible", "kayobe-ansible-user.yml"),
-                    utils.get_data_files_path("ansible", "yum.yml"),
-                    utils.get_data_files_path("ansible", "dnf.yml"),
                     utils.get_data_files_path("ansible", "pip.yml"),
                     utils.get_data_files_path(
                         "ansible", "kayobe-target-venv.yml"),
                     utils.get_data_files_path("ansible", "users.yml"),
+                    utils.get_data_files_path("ansible", "dnf.yml"),
                     utils.get_data_files_path("ansible", "dev-tools.yml"),
                     utils.get_data_files_path(
                         "ansible", "disable-selinux.yml"),
@@ -509,11 +498,17 @@ class TestCase(unittest.TestCase):
                     utils.get_data_files_path("ansible", "ip-routing.yml"),
                     utils.get_data_files_path("ansible", "snat.yml"),
                     utils.get_data_files_path("ansible", "disable-glean.yml"),
-                    utils.get_data_files_path("ansible", "ntp.yml"),
+                    utils.get_data_files_path("ansible", "timezone.yml"),
                     utils.get_data_files_path("ansible", "mdadm.yml"),
+                    utils.get_data_files_path("ansible", "luks.yml"),
                     utils.get_data_files_path("ansible", "lvm.yml"),
                     utils.get_data_files_path("ansible",
                                               "docker-devicemapper.yml"),
+                    utils.get_data_files_path(
+                        "ansible", "kolla-ansible-user.yml"),
+                    utils.get_data_files_path("ansible", "kolla-pip.yml"),
+                    utils.get_data_files_path(
+                        "ansible", "kolla-target-venv.yml"),
                 ],
                 limit="seed",
             ),
@@ -526,14 +521,10 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 [
-                    utils.get_data_files_path("ansible", "pip.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "kolla-target-venv.yml"),
                     utils.get_data_files_path("ansible", "kolla-host.yml"),
                     utils.get_data_files_path("ansible", "docker.yml"),
                 ],
                 limit="seed",
-                extra_vars={'pip_applicable_users': [None]},
             ),
             mock.call(
                 mock.ANY,
@@ -551,109 +542,6 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 "bootstrap-servers",
-                extra_vars={"ansible_user": "stack"},
-            ),
-        ]
-        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
-
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_config_dump")
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_playbooks")
-    @mock.patch.object(commands.KollaAnsibleMixin,
-                       "run_kolla_ansible_seed")
-    def test_seed_host_configure_kayobe_venv(self, mock_kolla_run, mock_run,
-                                             mock_dump):
-        command = commands.SeedHostConfigure(TestApp(), [])
-        parser = command.get_parser("test")
-        parsed_args = parser.parse_args([])
-        mock_dump.return_value = {
-            "seed": {
-                "ansible_python_interpreter": "/kayobe/venv/bin/python",
-                "kayobe_ansible_user": "stack",
-            }
-        }
-
-        result = command.run(parsed_args)
-        self.assertEqual(0, result)
-
-        expected_calls = [
-            mock.call(
-                mock.ANY,
-                "bootstrap-servers",
-                extra_vars={
-                    "ansible_python_interpreter": "/kayobe/venv/bin/python",
-                    "ansible_user": "stack",
-                },
-            ),
-        ]
-        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
-
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_config_dump")
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_playbooks")
-    @mock.patch.object(commands.KollaAnsibleMixin,
-                       "run_kolla_ansible_seed")
-    def test_seed_host_configure_kolla_venv(self, mock_kolla_run, mock_run,
-                                            mock_dump):
-        command = commands.SeedHostConfigure(TestApp(), [])
-        parser = command.get_parser("test")
-        parsed_args = parser.parse_args([])
-        mock_dump.return_value = {
-            "seed": {
-                "kayobe_ansible_user": "stack",
-                "kolla_ansible_target_venv": "/kolla/venv/bin/python",
-            }
-        }
-
-        result = command.run(parsed_args)
-        self.assertEqual(0, result)
-
-        expected_calls = [
-            mock.call(
-                mock.ANY,
-                "bootstrap-servers",
-                extra_vars={
-                    "ansible_python_interpreter": "/usr/bin/python",
-                    "ansible_user": "stack",
-                    "virtualenv": "/kolla/venv/bin/python",
-                },
-            ),
-        ]
-        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
-
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_config_dump")
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_playbooks")
-    @mock.patch.object(commands.KollaAnsibleMixin,
-                       "run_kolla_ansible_seed")
-    def test_seed_host_configure_both_venvs(self, mock_kolla_run, mock_run,
-                                            mock_dump):
-        command = commands.SeedHostConfigure(TestApp(), [])
-        parser = command.get_parser("test")
-        parsed_args = parser.parse_args([])
-        mock_dump.return_value = {
-            "seed": {
-                "ansible_python_interpreter": "/kayobe/venv/bin/python",
-                "kayobe_ansible_user": "stack",
-                "kolla_ansible_target_venv": "/kolla/venv/bin/python",
-            }
-        }
-
-        result = command.run(parsed_args)
-        self.assertEqual(0, result)
-
-        expected_calls = [
-            mock.call(
-                mock.ANY,
-                "bootstrap-servers",
-                extra_vars={
-                    "ansible_python_interpreter": "/kayobe/venv/bin/python",
-                    "ansible_user": "stack",
-                    "virtualenv": "/kolla/venv/bin/python",
-                },
             ),
         ]
         self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
@@ -892,6 +780,10 @@ class TestCase(unittest.TestCase):
         self.assertEqual(0, result)
 
         expected_calls = [
+            mock.call(
+                mock.ANY,
+                [utils.get_data_files_path("ansible", "seed-deploy-containers.yml")],  # noqa
+            ),
             mock.call(
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
@@ -908,8 +800,6 @@ class TestCase(unittest.TestCase):
                 [
                     utils.get_data_files_path(
                         "ansible", "overcloud-host-image-workaround-resolv.yml"),  # noqa
-                    utils.get_data_files_path(
-                        "ansible", "overcloud-host-image-workaround-cloud-init.yml"),  # noqa
                     utils.get_data_files_path(
                         "ansible", "seed-introspection-rules.yml"),
                     utils.get_data_files_path(
@@ -940,6 +830,10 @@ class TestCase(unittest.TestCase):
         self.assertEqual(0, result)
 
         expected_calls = [
+            mock.call(
+                mock.ANY,
+                [utils.get_data_files_path("ansible", "seed-deploy-containers.yml")],  # noqa
+            ),
             mock.call(
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
@@ -964,9 +858,6 @@ class TestCase(unittest.TestCase):
                     utils.get_data_files_path(
                         "ansible",
                         "overcloud-host-image-workaround-resolv.yml"),
-                    utils.get_data_files_path(
-                        "ansible",
-                        "overcloud-host-image-workaround-cloud-init.yml"),
                     utils.get_data_files_path(
                         "ansible",
                         "seed-introspection-rules.yml"),
@@ -1088,29 +979,18 @@ class TestCase(unittest.TestCase):
         ]
         self.assertEqual(expected_calls, mock_run.call_args_list)
 
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_config_dump")
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
     @mock.patch.object(commands.KollaAnsibleMixin,
                        "run_kolla_ansible_overcloud")
-    def test_overcloud_host_configure(self, mock_kolla_run, mock_run,
-                                      mock_dump):
+    def test_overcloud_host_configure(self, mock_kolla_run, mock_run):
         command = commands.OvercloudHostConfigure(TestApp(), [])
         parser = command.get_parser("test")
         parsed_args = parser.parse_args([])
-        mock_dump.return_value = {
-            "controller0": {"kayobe_ansible_user": "stack"}
-        }
 
         result = command.run(parsed_args)
         self.assertEqual(0, result)
 
-        expected_calls = [
-            mock.call(mock.ANY, hosts="overcloud", tags="dump-config")
-        ]
-        self.assertEqual(expected_calls, mock_dump.call_args_list)
-
         expected_calls = [
             mock.call(
                 mock.ANY,
@@ -1123,12 +1003,11 @@ class TestCase(unittest.TestCase):
                     utils.get_data_files_path("ansible", "ssh-known-host.yml"),
                     utils.get_data_files_path(
                         "ansible", "kayobe-ansible-user.yml"),
-                    utils.get_data_files_path("ansible", "yum.yml"),
-                    utils.get_data_files_path("ansible", "dnf.yml"),
                     utils.get_data_files_path("ansible", "pip.yml"),
                     utils.get_data_files_path(
                         "ansible", "kayobe-target-venv.yml"),
                     utils.get_data_files_path("ansible", "users.yml"),
+                    utils.get_data_files_path("ansible", "dnf.yml"),
                     utils.get_data_files_path("ansible", "dev-tools.yml"),
                     utils.get_data_files_path(
                         "ansible", "disable-selinux.yml"),
@@ -1137,11 +1016,17 @@ class TestCase(unittest.TestCase):
                     utils.get_data_files_path("ansible", "disable-glean.yml"),
                     utils.get_data_files_path(
                         "ansible", "disable-cloud-init.yml"),
-                    utils.get_data_files_path("ansible", "ntp.yml"),
+                    utils.get_data_files_path("ansible", "timezone.yml"),
                     utils.get_data_files_path("ansible", "mdadm.yml"),
+                    utils.get_data_files_path("ansible", "luks.yml"),
                     utils.get_data_files_path("ansible", "lvm.yml"),
                     utils.get_data_files_path("ansible",
                                               "docker-devicemapper.yml"),
+                    utils.get_data_files_path(
+                        "ansible", "kolla-ansible-user.yml"),
+                    utils.get_data_files_path("ansible", "kolla-pip.yml"),
+                    utils.get_data_files_path(
+                        "ansible", "kolla-target-venv.yml"),
                 ],
                 limit="overcloud",
             ),
@@ -1154,18 +1039,12 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 [
-                    utils.get_data_files_path("ansible", "pip.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "kolla-target-venv.yml"),
                     utils.get_data_files_path("ansible", "kolla-host.yml"),
                     utils.get_data_files_path("ansible", "docker.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "ceph-block-devices.yml"),
                     utils.get_data_files_path(
                         "ansible", "swift-block-devices.yml"),
                 ],
                 limit="overcloud",
-                extra_vars={"pip_applicable_users": [None]},
             ),
         ]
         self.assertEqual(expected_calls, mock_run.call_args_list)
@@ -1174,109 +1053,6 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 "bootstrap-servers",
-                extra_vars={"ansible_user": "stack"},
-            ),
-        ]
-        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
-
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_config_dump")
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_playbooks")
-    @mock.patch.object(commands.KollaAnsibleMixin,
-                       "run_kolla_ansible_overcloud")
-    def test_overcloud_host_configure_kayobe_venv(self, mock_kolla_run,
-                                                  mock_run, mock_dump):
-        command = commands.OvercloudHostConfigure(TestApp(), [])
-        parser = command.get_parser("test")
-        parsed_args = parser.parse_args([])
-        mock_dump.return_value = {
-            "controller0": {
-                "ansible_python_interpreter": "/kayobe/venv/bin/python",
-                "kayobe_ansible_user": "stack",
-            }
-        }
-
-        result = command.run(parsed_args)
-        self.assertEqual(0, result)
-
-        expected_calls = [
-            mock.call(
-                mock.ANY,
-                "bootstrap-servers",
-                extra_vars={
-                    "ansible_python_interpreter": "/kayobe/venv/bin/python",
-                    "ansible_user": "stack",
-                }
-            ),
-        ]
-        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
-
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_config_dump")
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_playbooks")
-    @mock.patch.object(commands.KollaAnsibleMixin,
-                       "run_kolla_ansible_overcloud")
-    def test_overcloud_host_configure_kolla_venv(self, mock_kolla_run,
-                                                 mock_run, mock_dump):
-        command = commands.OvercloudHostConfigure(TestApp(), [])
-        parser = command.get_parser("test")
-        parsed_args = parser.parse_args([])
-        mock_dump.return_value = {
-            "controller0": {
-                "kayobe_ansible_user": "stack",
-                "kolla_ansible_target_venv": "/kolla/venv/bin/python",
-            }
-        }
-
-        result = command.run(parsed_args)
-        self.assertEqual(0, result)
-
-        expected_calls = [
-            mock.call(
-                mock.ANY,
-                "bootstrap-servers",
-                extra_vars={
-                    "ansible_python_interpreter": "/usr/bin/python",
-                    "ansible_user": "stack",
-                    "virtualenv": "/kolla/venv/bin/python",
-                }
-            ),
-        ]
-        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
-
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_config_dump")
-    @mock.patch.object(commands.KayobeAnsibleMixin,
-                       "run_kayobe_playbooks")
-    @mock.patch.object(commands.KollaAnsibleMixin,
-                       "run_kolla_ansible_overcloud")
-    def test_overcloud_host_configure_both_venvs(self, mock_kolla_run,
-                                                 mock_run, mock_dump):
-        command = commands.OvercloudHostConfigure(TestApp(), [])
-        parser = command.get_parser("test")
-        parsed_args = parser.parse_args([])
-        mock_dump.return_value = {
-            "controller0": {
-                "ansible_python_interpreter": "/kayobe/venv/bin/python",
-                "kayobe_ansible_user": "stack",
-                "kolla_ansible_target_venv": "/kolla/venv/bin/python",
-            }
-        }
-
-        result = command.run(parsed_args)
-        self.assertEqual(0, result)
-
-        expected_calls = [
-            mock.call(
-                mock.ANY,
-                "bootstrap-servers",
-                extra_vars={
-                    "ansible_python_interpreter": "/kayobe/venv/bin/python",
-                    "ansible_user": "stack",
-                    "virtualenv": "/kolla/venv/bin/python",
-                }
             ),
         ]
         self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
@@ -1785,6 +1561,14 @@ class TestCase(unittest.TestCase):
                     "kayobe_action": "upgrade",
                 }
             ),
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path("ansible",
+                                              "public-openrc.yml"),
+                ],
+                ignore_limit=True,
+            ),
         ]
         self.assertEqual(expected_calls, mock_run.call_args_list)
 
@@ -1797,6 +1581,10 @@ class TestCase(unittest.TestCase):
                 mock.ANY,
                 "upgrade"
             ),
+            mock.call(
+                mock.ANY,
+                "post-deploy"
+            ),
         ]
         self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
 
@@ -2196,3 +1984,31 @@ class TestCase(unittest.TestCase):
             ),
         ]
         self.assertEqual(expected_calls, mock_run.call_args_list)
+
+
+class TestHookDispatcher(unittest.TestCase):
+
+    @mock.patch('kayobe.cli.commands.os.path')
+    def test_hook_ordering(self, mock_path):
+        mock_command = mock.MagicMock()
+        dispatcher = commands.HookDispatcher(command=mock_command)
+        dispatcher._find_hooks = mock.MagicMock()
+        dispatcher._find_hooks.return_value = [
+            "10-hook.yml",
+            "5-hook.yml",
+            "z-test-alphabetical.yml",
+            "10-before-hook.yml",
+            "5-multiple-dashes-in-name.yml",
+            "no-prefix.yml"
+        ]
+        expected_result = [
+            "5-hook.yml",
+            "5-multiple-dashes-in-name.yml",
+            "10-before-hook.yml",
+            "10-hook.yml",
+            "no-prefix.yml",
+            "z-test-alphabetical.yml",
+        ]
+        mock_path.realpath.side_effect = lambda x: x
+        actual = dispatcher.hooks("config/path", "pre")
+        self.assertListEqual(actual, expected_result)
